@@ -9,12 +9,14 @@
 #  http://homepage.mac.com/mmalc/CocoaExamples/controllers.html
 
 import objc
+from objc import super
 from PyObjCTools import AppHelper
 
 from RadiansToDegreesTransformer import RadiansToDegreesTransformer
-from Cocoa import *
+from Cocoa import NSDocument, NSValueTransformer, NSKeyedArchiver, NSKeyedUnarchiver
 
-class GraphicsBindingsDocument (NSDocument):
+
+class GraphicsBindingsDocument(NSDocument):
     graphicsView = objc.IBOutlet()
     shadowInspector = objc.IBOutlet()
     graphicsController = objc.IBOutlet()
@@ -24,14 +26,16 @@ class GraphicsBindingsDocument (NSDocument):
         self = super(GraphicsBindingsDocument, self).init()
         if self is None:
             return None
-        self.graphics = [] # NSMutableArray.array()
+        self.graphics = []  # NSMutableArray.array()
         self.bindings = []
         return self
 
     def windowNibName(self):
         return "GraphicsBindingsDocument"
 
-    def makeBinding_fromObject_toObject_withKeyPath_options_(self, key, fromObject, toObject, withKeyPath, options):
+    def makeBinding_fromObject_toObject_withKeyPath_options_(
+        self, key, fromObject, toObject, withKeyPath, options
+    ):
         self.bindings.append((fromObject, key))
         fromObject.bind_toObject_withKeyPath_options_(key, toObject, withKeyPath, options)
 
@@ -42,17 +46,41 @@ class GraphicsBindingsDocument (NSDocument):
         # we don't have palette items for them
 
         # allow the shadow inspector (joystick) to handle multiple selections
-        offsetOptions = { u"NSAllowsEditingMultipleValuesSelection" : True }
+        offsetOptions = {"NSAllowsEditingMultipleValuesSelection": True}
         angleOptions = {
-            u"NSValueTransformerName" :  u"RadiansToDegreesTransformer",
-            u"NSAllowsEditingMultipleValuesSelection" : True,
+            "NSValueTransformerName": "RadiansToDegreesTransformer",
+            "NSAllowsEditingMultipleValuesSelection": True,
         }
 
         BINDINGS = [
-            (u'graphics',  self.graphicsView, self.graphicsController, u'arrangedObjects', None),
-            (u'selectionIndexes', self.graphicsView, self.graphicsController, u'selectionIndexes', None),
-            (u'offset', self.shadowInspector, self.graphicsController, u'selection.shadowOffset', offsetOptions),
-            (u'angle', self.shadowInspector, self.graphicsController, u'selection.shadowAngle', angleOptions),
+            (
+                "graphics",
+                self.graphicsView,
+                self.graphicsController,
+                "arrangedObjects",
+                None,
+            ),
+            (
+                "selectionIndexes",
+                self.graphicsView,
+                self.graphicsController,
+                "selectionIndexes",
+                None,
+            ),
+            (
+                "offset",
+                self.shadowInspector,
+                self.graphicsController,
+                "selection.shadowOffset",
+                offsetOptions,
+            ),
+            (
+                "angle",
+                self.shadowInspector,
+                self.graphicsController,
+                "selection.shadowAngle",
+                angleOptions,
+            ),
         ]
         for binding in BINDINGS:
             self.makeBinding_fromObject_toObject_withKeyPath_options_(*binding)
@@ -73,5 +101,6 @@ class GraphicsBindingsDocument (NSDocument):
         self.graphics = NSKeyedUnarchiver.unarchiveObjectWithData_(data)
         return True
 
+
 vt = RadiansToDegreesTransformer.alloc().init()
-NSValueTransformer.setValueTransformer_forName_(vt, u"RadiansToDegreesTransformer")
+NSValueTransformer.setValueTransformer_forName_(vt, "RadiansToDegreesTransformer")
