@@ -7,25 +7,20 @@ Usage:
 from setuptools import setup
 
 plist = dict(
-    CFBundleDocumentTypes = [
+    CFBundleDocumentTypes=[
         dict(
             CFBundleTypeExtensions=["GraphicsBindings", "*"],
             CFBundleTypeName="GraphicsBindings File",
             CFBundleTypeRole="Editor",
             NSDocumentClass="GraphicsBindingsDocument",
-        ),
-    ],
+        )
+    ]
 )
 
 setup(
     name="GraphicsBinding",
     app=["GraphicsBindings.py"],
     data_files=["English.lproj"],
-    options=dict(py2app=dict(
-        plist=plist,
-    )),
-    setup_requires=[
-        "py2app",
-        "pyobjc-framework-Cocoa",
-    ]
+    options=dict(py2app=dict(plist=plist)),
+    setup_requires=["py2app", "pyobjc-framework-Cocoa"],
 )
