@@ -7,12 +7,16 @@
 #  The original version was written in Objective-C by Malcolm Crawford
 #  at http://homepage.mac.com/mmalc/CocoaExamples/controllers.html
 
-from AppKit import *
+import objc
+from objc import super
+from Cocoa import NSDocument, NSMutableArray, NSValueTransformer
+from Cocoa import NSKeyedArchiver, NSKeyedUnarchiver
 
 from Category import Category
 from PriorityToColourTransformer import PriorityToColourTransformer
 from OverdueTransformer import OverdueTransformer
 
+
 class ToDosDocument(NSDocument):
     nix = objc.IBOutlet()
     toDos = objc.ivar()
@@ -21,15 +25,15 @@ class ToDosDocument(NSDocument):
         self = super(ToDosDocument, self).init()
         if self is None:
             return None
-        self.toDos = NSMutableArray.array()
-        return self # if this line is missing you will get the
-                    # simple message: "Can't create new document"
+        self.toDos = NSMutableArray()
+        return self  # if this line is missing you will get the
+        # simple message: "Can't create new document"
 
     def categories(self):
         return Category.allCategories()
 
     def windowNibName(self):
-        return u"ToDosDocument"
+        return "ToDosDocument"
 
     def dataRepresentationOfType_(self, aType):
         return NSKeyedArchiver.archivedDataWithRootObject_(self.toDos)
@@ -38,10 +42,11 @@ class ToDosDocument(NSDocument):
         self.toDos = NSKeyedUnarchiver.unarchiveObjectWithData_(data)
         return True
 
+
 priorityTransformer = PriorityToColourTransformer.alloc().init()
 NSValueTransformer.setValueTransformer_forName_(
-    priorityTransformer, u"PriorityToColourTransformer")
+    priorityTransformer, "PriorityToColourTransformer"
+)
 
 overdueTransformer = OverdueTransformer.alloc().init()
-NSValueTransformer.setValueTransformer_forName_(
-    overdueTransformer, u"OverdueTransformer")
+NSValueTransformer.setValueTransformer_forName_(overdueTransformer, "OverdueTransformer")
