@@ -1,5 +1,5 @@
 #define PY_SSIZE_T_CLEAN
-#include <Python.h>
+#include "Python.h"
 #include "pyobjc-api.h"
 
 #import <CoreFoundation/CoreFoundation.h>
@@ -26,42 +26,33 @@
 #include "_CoreFoundation_CFTree.m"
 #include "_CoreFoundation_CFWriteStream.m"
 
-
 static PyMethodDef mod_methods[] = {
-    COREFOUNDATION_CFBAG_METHODS
-    COREFOUNDATION_CFBINARYHEAP_METHODS
-    COREFOUNDATION_BITVECTOR_METHODS
-    COREFOUNDATION_CALENDAR_METHODS
-    COREFOUNDATION_DICTIONARY_METHODS
+    COREFOUNDATION_CFBAG_METHODS COREFOUNDATION_CFBINARYHEAP_METHODS
+        COREFOUNDATION_BITVECTOR_METHODS COREFOUNDATION_CALENDAR_METHODS
+            COREFOUNDATION_DICTIONARY_METHODS
 #if MAC_OS_X_VERSION_10_5 <= MAC_OS_X_VERSION_MAX_ALLOWED
-    COREFOUNDATION_FILEDESCRIPTOR_METHODS
+                COREFOUNDATION_FILEDESCRIPTOR_METHODS
 #endif
-    COREFOUNDATION_MACHPORT_METHODS
-    COREFOUNDATION_MESSAGEPORT_METHODS
-    COREFOUNDATION_NUMBER_METHODS
-    COREFOUNDATION_NUMBERFORMATTER_METHODS
-    COREFOUNDATION_READSTREAM_METHODS
-    COREFOUNDATION_RUNLOOP_METHODS
-    COREFOUNDATION_RUNLOOPSOURCE_METHODS
-    COREFOUNDATION_RUNLOOPTIMER_METHODS
-    COREFOUNDATION_SET_METHODS
-    COREFOUNDATION_SOCKET_METHODS
-    COREFOUNDATION_TREE_METHODS
-    COREFOUNDATION_WRITESTREAM_METHODS
+                    COREFOUNDATION_MACHPORT_METHODS COREFOUNDATION_MESSAGEPORT_METHODS
+                        COREFOUNDATION_NUMBER_METHODS COREFOUNDATION_NUMBERFORMATTER_METHODS
+                            COREFOUNDATION_READSTREAM_METHODS
+                                COREFOUNDATION_RUNLOOP_METHODS
+                                    COREFOUNDATION_RUNLOOPSOURCE_METHODS
+                                        COREFOUNDATION_RUNLOOPTIMER_METHODS
+                                            COREFOUNDATION_SET_METHODS
+                                                COREFOUNDATION_SOCKET_METHODS
+                                                    COREFOUNDATION_TREE_METHODS
+                                                        COREFOUNDATION_WRITESTREAM_METHODS
 
-    { 0, 0, 0, 0 } /* sentinel */
+    {0, 0, 0, 0} /* sentinel */
 };
 
-
 /* Python glue */
 
 PyObjC_MODULE_INIT(_CoreFoundation)
 {
     PyObject* m;
-    m = PyObjC_MODULE_CREATE(_CoreFoundation)
-    if (!m) {
-        PyObjC_INITERROR();
-    }
+    m = PyObjC_MODULE_CREATE(_CoreFoundation) if (!m) { PyObjC_INITERROR(); }
 
     /* Some C functions aren't available at runtime (e.g. when compiling on
      * OS X 10.5 but running on 10.4), so we use "#pragma weak" to weakly
@@ -73,7 +64,8 @@ PyObjC_MODULE_INIT(_CoreFoundation)
      */
     COREFOUNDATION_FILEDESCRIPTOR_AFTER_CREATE
 
-    if (PyObjC_ImportAPI(m) == -1) PyObjC_INITERROR();
+    if (PyObjC_ImportAPI(m) == -1)
+        PyObjC_INITERROR();
 
     PyObjC_INITDONE();
 }
