@@ -2,27 +2,16 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
-
-class TestDateFormatter (TestCase):
+class TestDateFormatter(TestCase):
     def testTypeID(self):
         self.assertIsInstance(CFDateGetTypeID(), (int, long))
 
     def testConstants(self):
-        self.assertEqual(kCFDateFormatterNoStyle , 0)
-        self.assertEqual(kCFDateFormatterShortStyle , 1)
-        self.assertEqual(kCFDateFormatterMediumStyle , 2)
-        self.assertEqual(kCFDateFormatterLongStyle , 3)
-        self.assertEqual(kCFDateFormatterFullStyle , 4)
+        self.assertEqual(kCFDateFormatterNoStyle, 0)
+        self.assertEqual(kCFDateFormatterShortStyle, 1)
+        self.assertEqual(kCFDateFormatterMediumStyle, 2)
+        self.assertEqual(kCFDateFormatterLongStyle, 3)
+        self.assertEqual(kCFDateFormatterFullStyle, 4)
         self.assertIsInstance(kCFDateFormatterIsLenient, unicode)
         self.assertIsInstance(kCFDateFormatterTimeZone, unicode)
         self.assertIsInstance(kCFDateFormatterCalendarName, unicode)
@@ -52,16 +41,50 @@ class TestDateFormatter (TestCase):
         self.assertIsInstance(kCFDateFormatterShortStandaloneQuarterSymbols, unicode)
         self.assertIsInstance(kCFDateFormatterGregorianStartDate, unicode)
 
-    @min_os_level('10.6')
+        self.assertEqual(kCFISO8601DateFormatWithYear, 1 << 0)
+        self.assertEqual(kCFISO8601DateFormatWithMonth, 1 << 1)
+        self.assertEqual(kCFISO8601DateFormatWithWeekOfYear, 1 << 2)
+        self.assertEqual(kCFISO8601DateFormatWithDay, 1 << 4)
+        self.assertEqual(kCFISO8601DateFormatWithTime, 1 << 5)
+        self.assertEqual(kCFISO8601DateFormatWithTimeZone, 1 << 6)
+        self.assertEqual(kCFISO8601DateFormatWithSpaceBetweenDateAndTime, 1 << 7)
+        self.assertEqual(kCFISO8601DateFormatWithDashSeparatorInDate, 1 << 8)
+        self.assertEqual(kCFISO8601DateFormatWithColonSeparatorInTime, 1 << 9)
+        self.assertEqual(kCFISO8601DateFormatWithColonSeparatorInTimeZone, 1 << 10)
+        self.assertEqual(kCFISO8601DateFormatWithFractionalSeconds, 1 << 11)
+        self.assertEqual(
+            kCFISO8601DateFormatWithFullDate,
+            kCFISO8601DateFormatWithYear
+            | kCFISO8601DateFormatWithMonth
+            | kCFISO8601DateFormatWithDay
+            | kCFISO8601DateFormatWithDashSeparatorInDate,
+        )
+        self.assertEqual(
+            kCFISO8601DateFormatWithFullTime,
+            kCFISO8601DateFormatWithTime
+            | kCFISO8601DateFormatWithColonSeparatorInTime
+            | kCFISO8601DateFormatWithTimeZone
+            | kCFISO8601DateFormatWithColonSeparatorInTimeZone,
+        )
+        self.assertEqual(
+            kCFISO8601DateFormatWithInternetDateTime,
+            kCFISO8601DateFormatWithFullDate | kCFISO8601DateFormatWithFullTime,
+        )
+
+    @min_os_level("10.6")
     def testConstants10_6(self):
         self.assertIsInstance(kCFDateFormatterDoesRelativeDateFormattingKey, unicode)
 
-    @min_os_level('10.6')
+    @min_os_level("10.6")
     def testFunction10_6(self):
         self.assertResultIsCFRetained(CFDateFormatterCreateDateFormatFromTemplate)
         r = CFDateFormatterCreateDateFormatFromTemplate(None, "%Y-%m-%d", 0, None)
         self.assertIsInstance(r, unicode)
 
+    @min_os_level("10.12")
+    def testFunctions10_12(self):
+        self.assertResultIsCFRetained(CFDateFormatterCreateISO8601Formatter)
+
     def testTypes(self):
         self.assertIsCFType(CFDateFormatterRef)
 
@@ -75,7 +98,9 @@ class TestDateFormatter (TestCase):
         self.assertIsInstance(date, NSDate)
 
         self.assertResultIsCFRetained(CFDateFormatterCreate)
-        fmt = CFDateFormatterCreate(None, locale, kCFDateFormatterShortStyle, kCFDateFormatterLongStyle)
+        fmt = CFDateFormatterCreate(
+            None, locale, kCFDateFormatterShortStyle, kCFDateFormatterLongStyle
+        )
         self.assertIsInstance(fmt, CFDateFormatterRef)
         v = CFDateFormatterGetLocale(fmt)
         self.assertEqual(CFLocaleGetIdentifier(locale), CFLocaleGetIdentifier(v))
@@ -94,27 +119,34 @@ class TestDateFormatter (TestCase):
 
         v = CFDateFormatterCreateStringWithDate(None, fmt, date)
         self.assertIsInstance(v, unicode)
-        v = CFDateFormatterCreateStringWithAbsoluteTime(None, fmt, CFAbsoluteTimeGetCurrent())
+        v = CFDateFormatterCreateStringWithAbsoluteTime(
+            None, fmt, CFAbsoluteTimeGetCurrent()
+        )
         self.assertIsInstance(v, unicode)
         dt, rng = CFDateFormatterCreateDateFromString(None, fmt, v, (0, len(v)))
         self.assertIsInstance(dt, NSDate)
         self.assertIsInstance(rng, CFRange)
-        ok, rng, abstime = CFDateFormatterGetAbsoluteTimeFromString(fmt, v, (0, len(v)), None)
+        ok, rng, abstime = CFDateFormatterGetAbsoluteTimeFromString(
+            fmt, v, (0, len(v)), None
+        )
         self.assertIs(ok, True)
         self.assertIsInstance(rng, CFRange)
         self.assertIsInstance(abstime, float)
         self.assertResultIsCFRetained(CFDateFormatterCopyProperty)
         v = CFDateFormatterCopyProperty(fmt, kCFDateFormatterCalendarName)
         self.assertIsInstance(v, unicode)
-        CFDateFormatterSetProperty(fmt, kCFDateFormatterCalendarName, b"gregorian".decode('latin1'))
+        CFDateFormatterSetProperty(
+            fmt, kCFDateFormatterCalendarName, b"gregorian".decode("latin1")
+        )
         v = CFDateFormatterCopyProperty(fmt, kCFDateFormatterCalendarName)
         self.assertIsInstance(v, unicode)
-        self.assertEqual(v , b"gregorian".decode('latin1'))
+        self.assertEqual(v, b"gregorian".decode("latin1"))
         v = CFDateFormatterCopyProperty(fmt, kCFDateFormatterIsLenient)
         self.assertTrue(v is True or v is False)
         CFDateFormatterSetProperty(fmt, kCFDateFormatterIsLenient, True)
         v2 = CFDateFormatterCopyProperty(fmt, kCFDateFormatterIsLenient)
         self.assertIs(v2, True)
 
+
 if __name__ == "__main__":
     main()
