@@ -1,7 +1,8 @@
 from Foundation import *
 from PyObjCTools.TestSupport import *
 
-class TestAE (TestCase):
+
+class TestAE(TestCase):
     def testConstants(self):
         self.assertIsInstance(NSAppleScriptErrorMessage, unicode)
         self.assertIsInstance(NSAppleScriptErrorNumber, unicode)
@@ -11,7 +12,8 @@ class TestAE (TestCase):
 
     def testOutput(self):
         obj = NSAppleScript.alloc().initWithSource_(
-                'tell application Terminal to do Xscript "ls -l"')
+            'tell application Terminal to do Xscript "ls -l"'
+        )
         ok, error = obj.compileAndReturnError_(None)
         self.assertIs(ok, False)
         self.assertIsInstance(error, NSDictionary)
@@ -24,5 +26,6 @@ class TestAE (TestCase):
         self.assertArgIsOut(NSAppleScript.executeAppleEvent_error_, 1)
         self.assertArgIsOut(NSAppleScript.initWithContentsOfURL_error_, 1)
 
+
 if __name__ == "__main__":
     main()
