@@ -3,14 +3,9 @@ from PyObjCTools.TestSupport import *
 from Foundation import *
 
 
-try:
-    long
-except NameError:
-    long = int
-
-class TestNSCharacterSet (TestCase):
+class TestNSCharacterSet(TestCase):
     def testConstants(self):
-        self.assertEqual( NSOpenStepUnicodeReservedBase, 0xF400 )
+        self.assertEqual(NSOpenStepUnicodeReservedBase, 0xF400)
 
     def testMethods(self):
         self.assertResultIsBOOL(NSCharacterSet.characterIsMember_)
@@ -18,5 +13,6 @@ class TestNSCharacterSet (TestCase):
         self.assertResultIsBOOL(NSCharacterSet.isSupersetOfSet_)
         self.assertResultIsBOOL(NSCharacterSet.hasMemberInPlane_)
 
+
 if __name__ == "__main__":
     main()
