@@ -3,9 +3,8 @@ import sys
 from Foundation import *
 
 
-
-class TestNSDateInterval (TestCase):
-    @min_os_level('10.12')
+class TestNSDateInterval(TestCase):
+    @min_os_level("10.12")
     def testMethods(self):
         self.assertResultIsBOOL(NSDateInterval.isEqualToDateInterval_)
         self.assertResultIsBOOL(NSDateInterval.intersectsDateInterval_)
