@@ -1,7 +1,8 @@
 from AppKit import *
 from PyObjCTools.TestSupport import *
 
-class TestNSDockTile (TestCase):
+
+class TestNSDockTile(TestCase):
     def testMethods(self):
         self.assertResultIsBOOL(NSDockTile.showsApplicationBadge)
         self.assertArgIsBOOL(NSDockTile.setShowsApplicationBadge_, 0)
@@ -9,9 +10,10 @@ class TestNSDockTile (TestCase):
     def testConstants(self):
         self.assertEqual(NSAppKitVersionNumberWithDockTilePlugInSupport, 1001.0)
 
-    @min_sdk_level('10.10')
+    @min_sdk_level("10.10")
     def testProtocol(self):
-        objc.protocolNamed('NSDockTilePlugIn')
+        objc.protocolNamed("NSDockTilePlugIn")
+
 
 if __name__ == "__main__":
     main()
