@@ -4,20 +4,19 @@ import os
 from Foundation import *
 
 
-
-class TestNSHFSFileTypes (TestCase):
+class TestNSHFSFileTypes(TestCase):
     def testFunctions(self):
         v = NSHFSTypeCodeFromFileType("'rtfd'")
         self.assertIsInstance(v, (int, long))
         w = NSFileTypeForHFSTypeCode(v)
         self.assertIsInstance(w, unicode)
-        self.assertEqual(w, b"'rtfd'".decode('latin1'))
+        self.assertEqual(w, b"'rtfd'".decode("latin1"))
 
-        fname = '/Library/Documentation/Acknowledgements.rtf'
+        fname = "/Library/Documentation/Acknowledgements.rtf"
         if not os.path.exists(fname):
-            fname = '/Library/Documentation/AirPort Acknowledgements.rtf'
+            fname = "/Library/Documentation/AirPort Acknowledgements.rtf"
         if not os.path.exists(fname):
-            fname = '/Library/Documentation//iPod/Acknowledgements.rtf'
+            fname = "/Library/Documentation//iPod/Acknowledgements.rtf"
 
         if not os.path.exists(fname):
             self.fail("test file doesn't exist")
@@ -25,5 +24,6 @@ class TestNSHFSFileTypes (TestCase):
         v = NSHFSTypeOfFile(fname)
         self.assertIsInstance(v, unicode)
 
+
 if __name__ == "__main__":
     main()
