@@ -2,7 +2,8 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
-class TestNSHTTPCookieStorage (TestCase):
+
+class TestNSHTTPCookieStorage(TestCase):
     def testConstants(self):
         self.assertEqual(NSHTTPCookieAcceptPolicyAlways, 0)
         self.assertEqual(NSHTTPCookieAcceptPolicyNever, 1)
@@ -11,9 +12,12 @@ class TestNSHTTPCookieStorage (TestCase):
         self.assertIsInstance(NSHTTPCookieManagerAcceptPolicyChangedNotification, unicode)
         self.assertIsInstance(NSHTTPCookieManagerCookiesChangedNotification, unicode)
 
-    @min_os_level('10.10')
+    @min_os_level("10.10")
     def testMethods10_10(self):
-        self.assertArgIsBlock(NSHTTPCookieStorage.getCookiesForTask_completionHandler_, 1, b'v@')
+        self.assertArgIsBlock(
+            NSHTTPCookieStorage.getCookiesForTask_completionHandler_, 1, b"v@"
+        )
+
 
 if __name__ == "__main__":
     main()
