@@ -1,8 +1,8 @@
-
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-class TestNSScroller (TestCase):
+
+class TestNSScroller(TestCase):
     def testConstants(self):
         self.assertEqual(NSScrollerArrowsMaxEnd, 0)
         self.assertEqual(NSScrollerArrowsMinEnd, 1)
@@ -24,7 +24,7 @@ class TestNSScroller (TestCase):
         self.assertEqual(NSScrollerIncrementArrow, 0)
         self.assertEqual(NSScrollerDecrementArrow, 1)
 
-    @min_os_level('10.7')
+    @min_os_level("10.7")
     def testConstants10_7(self):
         self.assertEqual(NSScrollerStyleLegacy, 0)
         self.assertEqual(NSScrollerStyleOverlay, 1)
@@ -40,9 +40,10 @@ class TestNSScroller (TestCase):
         self.assertArgIsBOOL(NSScroller.drawKnobSlotInRect_highlight_, 1)
         self.assertArgIsBOOL(NSScroller.highlight_, 0)
 
-    @min_os_level('10.7')
+    @min_os_level("10.7")
     def testMethods10_7(self):
         self.assertResultIsBOOL(NSScroller.isCompatibleWithOverlayScrollers)
 
+
 if __name__ == "__main__":
     main()
