@@ -1,12 +1,12 @@
-
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-class TestNSTableColumn (TestCase):
+
+class TestNSTableColumn(TestCase):
     def testConstants(self):
         self.assertEqual(NSTableColumnNoResizing, 0)
-        self.assertEqual(NSTableColumnAutoresizingMask, ( 1 << 0 ))
-        self.assertEqual(NSTableColumnUserResizingMask, ( 1 << 1 ))
+        self.assertEqual(NSTableColumnAutoresizingMask, (1 << 0))
+        self.assertEqual(NSTableColumnUserResizingMask, (1 << 1))
 
     def testMethods(self):
         self.assertArgIsBOOL(NSTableColumn.setEditable_, 0)
@@ -14,7 +14,7 @@ class TestNSTableColumn (TestCase):
         self.assertArgIsBOOL(NSTableColumn.setResizable_, 0)
         self.assertResultIsBOOL(NSTableColumn.isResizable)
 
-    @min_os_level('10.5')
+    @min_os_level("10.5")
     def testMethods10_5(self):
         self.assertArgIsBOOL(NSTableColumn.setHidden_, 0)
         self.assertResultIsBOOL(NSTableColumn.isHidden)
